@@ -212,7 +212,7 @@ class PreseemGrpcClient(object):
                     return x
             except grpc.RpcError as err:
                 logging.debug('Error calling service: %s (%s)', err.code(), err.details())
-                if err.code() in (grpc.StatusCode.INTERNAL, grpc.StatusCode.NOT_FOUND, grpc.StatusCode.UNKNOWN, grpc.StatusCode.UNIMPLEMENTED, grpc.StatusCode.INVALID_ARGUMENT):
+                if err.code() in (grpc.StatusCode.INTERNAL, grpc.StatusCode.NOT_FOUND, grpc.StatusCode.UNKNOWN, grpc.StatusCode.UNIMPLEMENTED, grpc.StatusCode.INVALID_ARGUMENT, grpc.StatusCode.PERMISSION_DENIED):
                     raise
                 if retry_num == num_retries:
                     logging.warning('Error calling service: %s (%s)', err.code(), err.details())
